@@ -88,28 +88,50 @@ def cookiecutter(
     if replay:
         with import_patch:
             if isinstance(replay, bool):
-                context = load(config_dict['replay_dir'], template_name)
+                context_from_replayfile = load(config_dict['replay_dir'], template_name)
             else:
                 path, template_name = os.path.split(os.path.splitext(replay)[0])
-                context = load(path, template_name)
-    else:
-        context_file = os.path.join(repo_dir, 'cookiecutter.json')
-        logger.debug('context_file is %s', context_file)
+                context_from_replayfile = load(path, template_name)
 
+    context_file = os.path.join(repo_dir, 'cookiecutter.json')
+    logger.debug('context_file is %s', context_file)
+
+    if replay:
+        context = generate_context(
+            context_file=context_file,
+            default_context=config_dict['default_context'],
+            extra_context=None,
+        )
+        logger.debug('replayfile context: %s', context_from_replayfile)
+        items_for_prompting = {
+            k: v
+            for k, v in context['cookiecutter'].items()
+            if k not in context_from_replayfile['cookiecutter'].keys()
+        }
+        context_for_prompting = {}
+        context_for_prompting['cookiecutter'] = items_for_prompting
+        logger.debug('prompting context: %s', context_for_prompting)
+    else:
         context = generate_context(
             context_file=context_file,
             default_context=config_dict['default_context'],
             extra_context=extra_context,
         )
+        context_for_prompting = context
+    # preserve the original cookiecutter options
+    # print(context['cookiecutter'])
+    context['_cookiecutter'] = {
+        k: v for k, v in context['cookiecutter'].items() if not k.startswith("_")
+    }
 
-        # preserve the original cookiecutter options
-        context['_cookiecutter'] = context['cookiecutter']
-
-        # prompt the user to manually configure at the command line.
-        # except when 'no-input' flag is set
-        with import_patch:
-            context['cookiecutter'] = prompt_for_config(context, no_input)
+    # prompt the user to manually configure at the command line.
+    # except when 'no-input' flag is set
 
+    with import_patch:
+        if context_for_prompting['cookiecutter']:
+            context['cookiecutter'].update(
+                prompt_for_config(context_for_prompting, no_input)
+            )
         if "template" in context["cookiecutter"]:
             nested_template = re.search(
                 r'\((.*?)\)', context["cookiecutter"]["template"]
@@ -131,16 +153,17 @@ def cookiecutter(
                 keep_project_on_failure=keep_project_on_failure,
             )
 
-        # include template dir or url in the context dict
-        context['cookiecutter']['_template'] = template
+    logger.debug('contex is %s', context)
 
-        # include repo dir or url in the context dict
-        context['cookiecutter']['_repo_dir'] = repo_dir
+    # include template dir or url in the context dict
+    context['cookiecutter']['_template'] = template
 
-        # include output+dir in the context dict
-        context['cookiecutter']['_output_dir'] = os.path.abspath(output_dir)
+    # include output+dir in the context dict
+    context['cookiecutter']['_output_dir'] = os.path.abspath(output_dir)
+    # include repo dir or url in the context dict
+    context['cookiecutter']['_repo_dir'] = repo_dir
 
-        dump(config_dict['replay_dir'], template_name, context)
+    dump(config_dict['replay_dir'], template_name, context)
 
     # Create project from local context and project template.
     with import_patch:
