@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
-
 """Tests to verify correct work with user configs and system/user variables inside."""
-
 import os
 import shutil
 
@@ -49,6 +46,14 @@ def custom_config():
             'full_name': 'Firstname Lastname',
             'email': 'firstname.lastname@gmail.com',
             'github_username': 'example',
+            'project': {
+                'description': 'description',
+                'tags': [
+                    'first',
+                    'second',
+                    'third',
+                ],
+            },
         },
         'cookiecutters_dir': '/home/example/some-path-to-templates',
         'replay_dir': '/home/example/some-path-to-replay-files',
