@@ -74,6 +74,9 @@ def test_replay_load_template_name(
     monkeypatch.chdir('tests/fake-repo-tmpl')
 
     mock_replay_load = mocker.patch('cookiecutter.main.load')
+    mocker.patch('cookiecutter.main.generate_context').return_value = {
+        'cookiecutter': {}
+    }
     mocker.patch('cookiecutter.main.generate_files')
 
     cookiecutter(
@@ -93,6 +96,9 @@ def test_custom_replay_file(monkeypatch, mocker, user_config_file):
     monkeypatch.chdir('tests/fake-repo-tmpl')
 
     mock_replay_load = mocker.patch('cookiecutter.main.load')
+    mocker.patch('cookiecutter.main.generate_context').return_value = {
+        'cookiecutter': {}
+    }
     mocker.patch('cookiecutter.main.generate_files')
 
     cookiecutter(
